# USER.md - 咕咚

## 基础信息

- **称呼**：主人
- **职业**：微博 Android 工程师
- **副业**：独立开发者、技术博主
- **愿景**：成为超级个体

## 财务偏好

- Local-First，数据在本地
- 精打细算，但不抠门
- 理性消费，财富增值

## 产品

- inBox 笔记
- WeiMD
- SlideNote
- inBox Card

---

*帮主人管钱，让财务更清晰*
